<!DOCTYPE TS><TS>
<context>
    <name>QStarDict::CSSEdit</name>
    <message>
        <source>Preview</source>
        <translation>預覽</translation>
    </message>
    <message>
        <source>Element</source>
        <translation>元素</translation>
    </message>
    <message>
        <source>Foreground</source>
        <translation>前景</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <source>Select element</source>
        <translation>選取元素</translation>
    </message>
    <message>
        <source>Click to select color</source>
        <translation>點選色彩</translation>
    </message>
    <message>
        <source>#000000</source>
        <translation>#000000</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>字型</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Select font</source>
        <translation>選取字型</translation>
    </message>
    <message>
        <source>Select font size</source>
        <translation>選取字型大小</translation>
    </message>
    <message>
        <source>pt</source>
        <translation>pt</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>粗體</translation>
    </message>
    <message>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>斜體</translation>
    </message>
    <message>
        <source>I</source>
        <translation>I</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>底線</translation>
    </message>
    <message>
        <source>U</source>
        <translation>U</translation>
    </message>
</context>
<context>
    <name>QStarDict::DictBrowser</name>
    <message>
        <source>The word &lt;b&gt;%1&lt;/b&gt; is not found.</source>
        <translation>找不到單字 &lt;b&gt;%1&lt;/b&gt; </translation>
    </message>
</context>
<context>
    <name>QStarDict::DictWidget</name>
    <message>
        <source>Save translation</source>
        <translation>儲存翻譯</translation>
    </message>
    <message>
        <source>HTML files (*.html, *.htm)</source>
        <translation>HTML檔案(*.html, *.htm)</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>文字檔</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Cannot save translation as %1</source>
        <translation>無法將翻譯儲存為 %1</translation>
    </message>
    <message>
        <source>Go to &amp;previous translation</source>
        <translation>前一個翻譯 (&amp;p)</translation>
    </message>
    <message>
        <source>Go to &amp;next translation</source>
        <translation>後一個翻譯 (&amp;n)</translation>
    </message>
    <message>
        <source>&amp;Save to file</source>
        <translation>儲存到檔案(&amp;S)</translation>
    </message>
    <message>
        <source>Speak &amp;word</source>
        <translation>讀出單字 (&amp;w)</translation>
    </message>
    <message>
        <source>Prin&amp;t translation</source>
        <translation>列印翻譯(&amp;t)</translation>
    </message>
</context>
<context>
    <name>QStarDict::MainWindow</name>
    <message>
        <source>About QStarDict</source>
        <translation>關於 QStarDict</translation>
    </message>
    <message>
        <source>&lt;b&gt;QStarDict %1 &lt;/b&gt; - Qt version of StarDict&lt;br&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>Copyright (C) 2007-2009 Alexander Rodin &lt;a href=&quot;http://qstardict.ylsoftware.com&quot;&gt;http://qstardict.ylsoftware.com&lt;/a&gt;</source>
        <translation>版權  (C) 2007-2009 Alexander Rodin &lt;a href=&quot;http://qstardict.ylsoftware.com&quot;&gt;http://qstardict.ylsoftware.com&lt;/a&gt;</translation>
    </message>
    <message>
        <source>QStarDict</source>
        <translation>QStarDict</translation>
    </message>
    <message>
        <source>%1 - QStarDict</source>
        <translation>%1 - QStarDict</translation>
    </message>
    <message>
        <source>Clear the search box</source>
        <translation>清除搜尋框</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Fuzzy query</source>
        <translation>模糊查詢</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <source>Words list</source>
        <translation>字彙清單</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>說明(&amp;H)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;設定</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>離開(&amp;Q)</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation> 關於  Qt</translation>
    </message>
    <message>
        <source>&amp;Configure QStarDict</source>
        <translation>設定 QStarDict(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Scan</source>
        <translation>取詞(&amp;S)</translation>
    </message>
    <message>
        <source>QStarDict &amp;Help</source>
        <translation>QStarDict 說明(&amp;H)</translation>
    </message>
    <message>
        <source>F1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QStarDict::SettingsDialog</name>
    <message>
        <source>Enabled</source>
        <translation>啟用</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Plugin</source>
        <translation>外掛程式</translation>
    </message>
    <message>
        <source>Information about dictionary &quot;%1&quot;</source>
        <translation>字典&quot;%1&quot; 的資訊</translation>
    </message>
    <message>
        <source>&lt;b&gt;Name:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;字典名稱:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Plugin:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;外掛程式：&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>&lt;b&gt;Description:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;說明：&lt;/b&gt; %1</translation>
    </message>
    <message>
        <source>Information about %1 plugin</source>
        <translation>關於外掛程式 %1 的資訊</translation>
    </message>
    <message>
        <source>&lt;b&gt;Version:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;版本：&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Authors:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;作者：&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;br&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;b&gt;Can search similar words:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;可以搜尋相似單字：&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>no</source>
        <translation>否</translation>
    </message>
    <message>
        <source>QStarDict Settings</source>
        <translation>QStarDict 設定</translation>
    </message>
    <message>
        <source>Show information about dictionary</source>
        <translation>顯示字典資訊</translation>
    </message>
    <message>
        <source>Global settings</source>
        <translation>全域設定</translation>
    </message>
    <message>
        <source>Instant search</source>
        <translation>即時搜尋</translation>
    </message>
    <message>
        <source>Pronounce words using this command:</source>
        <translation>使用如下指令發音</translation>
    </message>
    <message>
        <source>Enter cmd for the speaching program.&lt;br&gt;If cmd contains &quot;%s&quot; it will be replaced to word, else word will be writen to stdin of speech process.</source>
        <translation></translation>
    </message>
    <message>
        <source>Dictionaries</source>
        <translation>字典</translation>
    </message>
    <message>
        <source>Move up</source>
        <translation>上移</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Move down</source>
        <translation>下移</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation>顯示資訊</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>外掛程式</translation>
    </message>
    <message>
        <source>Show information about plugin</source>
        <translation>顯示外掛程式資訊</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>資訊</translation>
    </message>
    <message>
        <source>Configure plugin</source>
        <translation>設定外掛程式</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Popup window</source>
        <translation>快顯視窗</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>行為</translation>
    </message>
    <message>
        <source>Pronounce the word</source>
        <translation>單字發音</translation>
    </message>
    <message>
        <source>Timeout before hide after mouse over</source>
        <translation>滑鼠懸停隱藏逾時</translation>
    </message>
    <message>
        <source>Don&apos;t hide</source>
        <translation>不隱藏</translation>
    </message>
    <message>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <source>Show only if modifier pressed</source>
        <translation>顯示，僅當按下</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Win</source>
        <translation>Win</translation>
    </message>
    <message>
        <source>Scan selection</source>
        <translation>選取區取詞</translation>
    </message>
    <message>
        <source>Show if word not found</source>
        <translation>當未找到字時顯示</translation>
    </message>
    <message>
        <source>Apperance</source>
        <translation>外觀</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>不透明度</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Default width</source>
        <translation>預設寬度</translation>
    </message>
    <message>
        <source>Default height</source>
        <translation>預設高度</translation>
    </message>
    <message>
        <source>&lt;b&gt;Author:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;作者:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words count:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;單字數:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <source>All translation</source>
        <translation>所有的翻譯</translation>
    </message>
    <message>
        <source>Dictionary name</source>
        <translation>字典名稱</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>標題</translation>
    </message>
    <message>
        <source>Explanation</source>
        <translation></translation>
    </message>
    <message>
        <source>Abbreviation</source>
        <translation>縮寫</translation>
    </message>
    <message>
        <source>Example</source>
        <translation>範例</translation>
    </message>
    <message>
        <source>Transcription</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QStarDict::TrayIcon</name>
    <message>
        <source>QStarDict</source>
        <translation>QStarDict</translation>
    </message>
    <message>
        <source>&amp;Scan</source>
        <translation>取詞(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Configure QStarDict</source>
        <translation>設定 QStarDict(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>離開(&amp;Q)</translation>
    </message>
    <message>
        <source>QStarDict: scanning is %1</source>
        <translation>QStarDict: 取詞已%1</translation>
    </message>
    <message>
        <source>enabled</source>
        <translation>啟用</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>停用</translation>
    </message>
</context>
</TS>
